@@ -18,9 +18,7 @@ from bamboo_engine.handler import register_handler, NodeHandler, ExecuteResult
 
 @register_handler(NodeType.ConvergeGateway)
 class ConvergeGatewayHandler(NodeHandler):
-    def execute(
-        self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str
-    ) -> ExecuteResult:
+    def execute(self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str) -> ExecuteResult:
         """
         节点的 execute 处理逻辑
 
@@ -32,9 +30,7 @@ class ConvergeGatewayHandler(NodeHandler):
         :rtype: ExecuteResult
         """
 
-        self.runtime.set_state(
-            node_id=self.node.id, to_state=states.FINISHED, set_archive_time=True
-        )
+        self.runtime.set_state(node_id=self.node.id, to_state=states.FINISHED, set_archive_time=True)
 
         return ExecuteResult(
             should_sleep=False,
